import { Component, OnInit, OnDestroy } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { Response } from '@angular/http';

import { Observable } from 'rxjs/Rx';
import { NgbActiveModal, NgbModalRef } from '@ng-bootstrap/ng-bootstrap';
import { JhiEventManager, JhiAlertService } from 'ng-jhipster';

import { Geocity } from './geocity.model';
import { GeocityPopupService } from './geocity-popup.service';
import { GeocityService } from './geocity.service';

@Component({
    selector: 'jhi-geocity-dialog',
    templateUrl: './geocity-dialog.component.html'
})
export class GeocityDialogComponent implements OnInit {

    geocity: Geocity;
    isSaving: boolean;

    constructor(
        public activeModal: NgbActiveModal,
        private alertService: JhiAlertService,
        private geocityService: GeocityService,
        private eventManager: JhiEventManager
    ) {
    }

    ngOnInit() {
        this.isSaving = false;
    }

    clear() {
        this.activeModal.dismiss('cancel');
    }

    save() {
        this.isSaving = true;
        if (this.geocity.id !== undefined) {
            this.subscribeToSaveResponse(
                this.geocityService.update(this.geocity));
        } else {
            this.subscribeToSaveResponse(
                this.geocityService.create(this.geocity));
        }
    }

    private subscribeToSaveResponse(result: Observable<Geocity>) {
        result.subscribe((res: Geocity) =>
            this.onSaveSuccess(res), (res: Response) => this.onSaveError(res));
    }

    private onSaveSuccess(result: Geocity) {
        this.eventManager.broadcast({ name: 'geocityListModification', content: 'OK'});
        this.isSaving = false;
        this.activeModal.dismiss(result);
    }

    private onSaveError(error) {
        try {
            error.json();
        } catch (exception) {
            error.message = error.text();
        }
        this.isSaving = false;
        this.onError(error);
    }

    private onError(error) {
        this.alertService.error(error.message, null, null);
    }
}

@Component({
    selector: 'jhi-geocity-popup',
    template: ''
})
export class GeocityPopupComponent implements OnInit, OnDestroy {

    routeSub: any;

    constructor(
        private route: ActivatedRoute,
        private geocityPopupService: GeocityPopupService
    ) {}

    ngOnInit() {
        this.routeSub = this.route.params.subscribe((params) => {
            if ( params['id'] ) {
                this.geocityPopupService
                    .open(GeocityDialogComponent as Component, params['id']);
            } else {
                this.geocityPopupService
                    .open(GeocityDialogComponent as Component);
            }
        });
    }

    ngOnDestroy() {
        this.routeSub.unsubscribe();
    }
}
